import pygame
import numpy as np
from scripts.tiles import Tilemap
from scripts.entities import Entity
from scripts.utils import load_image, load_images

# SETTINGS
WIDTH = 1280
HEIGHT = 720
TITLE = 'YuGiOh Tag Force Clone'

class Game:
    def __init__(self):
        pygame.init()
        self.screen = pygame.display.set_mode((WIDTH, HEIGHT))
        self.display = pygame.Surface((WIDTH//2, HEIGHT//2))
        
        pygame.display.set_caption(TITLE)
        self.clock = pygame.time.Clock()

        self.player = Entity(self, 'player', (50.0,200.0), (8, 15))
        self.assets = {
            'player' : load_image('entities/player.png'),
            'grass' : load_images('tiles/grass/'),
            'stone' : load_images('tiles/stone/')
        }
        self.tilemap = Tilemap(self, (32,32), 'map_1.csv') 
    def run(self):
        self.status = True
        while self.status:
            self.display.fill('white')
            delta = np.array([0.0,0.0])
            for event in pygame.event.get():
                if event.type == pygame.QUIT:
                    self.status = False
            keys = pygame.key.get_pressed()
            if keys[pygame.K_LEFT]:
                delta[0] -= 1
            if keys[pygame.K_RIGHT]:
                delta[0] += 1
            if keys[pygame.K_UP]:
                delta[1] -= 1
            if keys[pygame.K_DOWN]:
                delta[1] += 1
            self.player.update(delta)
            self.tilemap.render(self.display)
            self.player.render(self.display)
            self.screen.blit(pygame.transform.scale_by(self.display,2), (0,0))
            pygame.display.update()
            self.clock.tick(60)
        pygame.quit()

Game().run()
